export interface SignatureInspectorConfiguration {
    text?: string[];
    textPosition?: string;
    width?: number;
    height?: number;
}
export interface SignerServiceConfiguration {
    timestampServer?: string;
    defaultLocation?: string;
    inspector?: SignatureInspectorConfiguration;
    use?: 'SignerService' | 'HaricaSignerService' | string;
    configurable?: boolean;
    verificationUrl?: string;
}
export interface Certificate {
    version: number;
    subjectDN: string;
    sigAlgName?: string;
    sigAlgOID?: string;
    issuerDN: string;
    serialNumber: any;
    notAfter: string;
    notBefore: string;
    expired: boolean;
    thumbprint: string;
    commonName: string;
}
export interface VerifySignatureResult {
    valid: boolean;
    certificates: Certificate[];
    signatureProperties?: {
        signingDate: string;
        reason: string;
        signingCertificate: Certificate;
    };
}
export declare abstract class SignerService {
    static SINGER_URI: string;
    static DEFAULT_SIGN_POSITION: string;
    protected signerAuthorization: string;
    constructor();
    abstract get status(): Promise<any>;
    abstract authenticate({ username, password, rememberMe }: {
        username?: string;
        password?: string;
        rememberMe?: boolean;
    }): Promise<boolean>;
    get authorization(): string;
    abstract getCertificates(force?: boolean): Promise<Certificate[]>;
    abstract queryStatus(): Promise<any>;
    abstract sign(form: FormData): Promise<any>;
    abstract requestVerificationCode(): Promise<boolean>;
    setLastCertificate(thumbprint: string): void;
    getLastCertificate(): string;
    destroy(): void;
    getInspectorUrl(): string;
    protected inspectPosition(blob: Blob, configuration: SignatureInspectorConfiguration): Promise<any>;
    abstract get requiresVerificationCode(): boolean;
    abstract get requiresVerificationCodeRequest(): boolean;
    abstract confirmVerificationCode(): Promise<any>;
    abstract get requiresUsernamePassword(): boolean;
    abstract getVerificationUrl(): string;
    abstract verifyDocument(file: any): Promise<VerifySignatureResult[]>;
}
//# sourceMappingURL=SignerService.d.ts.map